==> apigateway-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnAccountProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::Account`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:22:40.380Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnAccountProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ApiGateway::Account.CloudWatchRoleArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getCloudWatchRoleArn();

    /**
     * @return a {@link Builder} of {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String cloudWatchRoleArn;

        /**
         * Sets the value of CloudWatchRoleArn
         * @param cloudWatchRoleArn `AWS::ApiGateway::Account.CloudWatchRoleArn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder cloudWatchRoleArn(java.lang.String cloudWatchRoleArn) {
            this.cloudWatchRoleArn = cloudWatchRoleArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAccountProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnAccountProps build() {
            return new Jsii$Proxy(cloudWatchRoleArn);
        }

    }

    /**
     * An implementation for {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAccountProps {
        private final java.lang.String cloudWatchRoleArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.cloudWatchRoleArn = this.jsiiGet("cloudWatchRoleArn", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String cloudWatchRoleArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudWatchRoleArn = cloudWatchRoleArn;
        }

        @Override
        public java.lang.String getCloudWatchRoleArn() {
            return this.cloudWatchRoleArn;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getCloudWatchRoleArn() != null) {
                obj.set("cloudWatchRoleArn", om.valueToTree(this.getCloudWatchRoleArn()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAccountProps.Jsii$Proxy that = (CfnAccountProps.Jsii$Proxy) o;

            return this.cloudWatchRoleArn != null ? this.cloudWatchRoleArn.equals(that.cloudWatchRoleArn) : that.cloudWatchRoleArn == null;
        }

        @Override
        public int hashCode() {
            int result = this.cloudWatchRoleArn != null ? this.cloudWatchRoleArn.hashCode() : 0;
            return result;
        }

    }
}

==> apigateway-1.10.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnAccountProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::Account`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-30T08:39:26.049Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnAccountProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGateway::Account.CloudWatchRoleArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getCloudWatchRoleArn();

    /**
     * @return a {@link Builder} of {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String cloudWatchRoleArn;

        /**
         * Sets the value of CloudWatchRoleArn
         * @param cloudWatchRoleArn `AWS::ApiGateway::Account.CloudWatchRoleArn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder cloudWatchRoleArn(java.lang.String cloudWatchRoleArn) {
            this.cloudWatchRoleArn = cloudWatchRoleArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAccountProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnAccountProps build() {
            return new Jsii$Proxy(cloudWatchRoleArn);
        }
    }

    /**
     * An implementation for {@link CfnAccountProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAccountProps {
        private final java.lang.String cloudWatchRoleArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.cloudWatchRoleArn = this.jsiiGet("cloudWatchRoleArn", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String cloudWatchRoleArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudWatchRoleArn = cloudWatchRoleArn;
        }

        @Override
        public java.lang.String getCloudWatchRoleArn() {
            return this.cloudWatchRoleArn;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getCloudWatchRoleArn() != null) {
                obj.set("cloudWatchRoleArn", om.valueToTree(this.getCloudWatchRoleArn()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAccountProps.Jsii$Proxy that = (CfnAccountProps.Jsii$Proxy) o;

            return this.cloudWatchRoleArn != null ? this.cloudWatchRoleArn.equals(that.cloudWatchRoleArn) : that.cloudWatchRoleArn == null;
        }

        @Override
        public int hashCode() {
            int result = this.cloudWatchRoleArn != null ? this.cloudWatchRoleArn.hashCode() : 0;
            return result;
        }
    }
}
